==> code-saturne_4.0.2%2Brepack.orig.tar.gz: code-saturne-4.0.2.orig/docs/doxygen/examples/cs_user_tabs.h <==
/*============================================================================
 * Code_Saturne documentation page
 *============================================================================*/

/*
  This file is part of Code_Saturne, a general-purpose CFD tool.

  Copyright (C) 1998-2015 EDF S.A.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2 of the License, or (at your option) any later
  version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
  Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*----------------------------------------------------------------------------*/

/*!
  \page cs_user_examples User examples

Here is a list of user examples. Thorougly documented snippets are provided.

   - \subpage cs_user_initialization "Physical fields user initialization"
   - \subpage cs_user_boundary_conditions_examples "User boundary conditions definitions"
   - \subpage les_inflow "Inflow Boundary conditions for LES"
   - \subpage f_parameters
   - \subpage parameters
   - \subpage cavit
   - \subpage physical_properties
   - \subpage drift_coal_scalars
   - \subpage drift_scalars
   - \subpage cs_porosity
   - \subpage cs_head_losses
   - \subpage cs_lagrangian_particle_tracking_module
   - \subpage cs_user_source_terms
   - \subpage cs_user_mass_source_terms
   - \subpage cs_user_boundary_conditions_ale
   - \subpage cs_user_radiative_transfer
   - \subpage cs_user_extra_operations_examples "User extra operations"
   - \subpage cs_user_extra_operations-nusselt_calculation
   - \subpage cs_user_source_terms-scalar_in_a_channel
*/

==> code-saturne_4.2.1%2Brepack.orig.tar.gz: code-saturne-4.2.1.orig/docs/doxygen/examples/cs_user_tabs.h <==
/*============================================================================
 * Code_Saturne documentation page
 *============================================================================*/

/*
  This file is part of Code_Saturne, a general-purpose CFD tool.

  Copyright (C) 1998-2016 EDF S.A.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2 of the License, or (at your option) any later
  version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
  Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*----------------------------------------------------------------------------*/

/*!
  \page cs_user_examples User examples

Here is a list of user examples. Thorougly documented snippets are provided.

   - \subpage cs_user_initialization "Physical fields user initialization"
   - \subpage cs_user_boundary_conditions_examples "User boundary condition definitions"
   - \subpage les_inflow "Inflow Boundary conditions for LES"
   - \subpage f_parameters
   - \subpage parameters
   - \subpage cavit
   - \subpage physical_properties
   - \subpage drift_coal_scalars
   - \subpage drift_scalars
   - \subpage cs_porosity
   - \subpage cs_head_losses
   - \subpage cs_lagrangian_particle_tracking_module
   - \subpage cs_user_source_terms
   - \subpage cs_user_mass_source_terms
   - \subpage cs_user_boundary_conditions_ale
   - \subpage cs_user_radiative_transfer
   - \subpage cs_user_extra_operations_examples "User extra operations"
   - \subpage cs_user_extra_operations-nusselt_calculation
   - \subpage cs_user_source_terms-scalar_in_a_channel
   - \subpage richards
*/
